
# Python API for XFLR5

This is the python package for running scripts and interfacing with [xflrpy](https://github.com/nikhil-sethi/xflrpy).

Note: This repository is in intial development phase. 
There might be:
- Some instability 
- Breaking changes without updating major versions until the first release. 

Any contributions/constructive criticism is welcome. Use github issues to roast me.

## How to Use
See [examples](https://github.com/nikhil-sethi/xflrpy/blob/rpc/PythonClient/examples)

## Dependencies
This package depends on `msgpack` and would automatically install `msgpack-rpc-python` (this may need administrator/sudo prompt):
```
pip install msgpack-rpc-python
```
